@@ -27,7 +27,7 @@
 
 #include "urldata.h"
 #include "strcase.h"
-#include "strdup.h"
+#include "curlx/strdup.h"
 #include "http_aws_sigv4.h"
 #include "curl_sha256.h"
 #include "transfer.h"
@@ -405,7 +405,7 @@ static CURLcode make_headers(struct Curl_easy *data,
     if(data->state.aptr.host) {
       /* remove /r/n as the separator for canonical request must be '\n' */
       size_t pos = strcspn(data->state.aptr.host, "\n\r");
-      fullhost = Curl_memdup0(data->state.aptr.host, pos);
+      fullhost = curlx_memdup0(data->state.aptr.host, pos);
     }
     else
       fullhost = curl_maprintf("host:%s", hostname);
@@ -732,7 +732,7 @@ UNITTEST CURLcode canon_query(const char *query, struct dynbuf *dq)
     size_t in_key_len;
     const char *offset;
     size_t query_part_len = curlx_dyn_len(&query_array[index]);
-    char *query_part = curlx_dyn_ptr(&query_array[index]);
+    const char *query_part = curlx_dyn_ptr(&query_array[index]);
 
     in_key = query_part;
 
@@ -788,8 +788,8 @@ UNITTEST CURLcode canon_query(const char *query, struct dynbuf *dq)
     if(index)
       result = curlx_dyn_addn(dq, "&", 1);
     if(!result) {
-      char *key_ptr = curlx_dyn_ptr(&encoded_query_array[index].key);
-      char *value_ptr = curlx_dyn_ptr(&encoded_query_array[index].value);
+      const char *key_ptr = curlx_dyn_ptr(&encoded_query_array[index].key);
+      const char *value_ptr = curlx_dyn_ptr(&encoded_query_array[index].value);
       size_t vlen = curlx_dyn_len(&encoded_query_array[index].value);
       if(value_ptr && vlen) {
         result = curlx_dyn_addf(dq, "%s=%s", key_ptr, value_ptr);
@@ -986,8 +986,8 @@ CURLcode Curl_output_aws_sigv4(struct Curl_easy *data)
     goto fail;
 
   result = canon_path(data->state.up.path, strlen(data->state.up.path),
-                        &canonical_path,
-                        should_urlencode(&service));
+                      &canonical_path,
+                      should_urlencode(&service));
   if(result)
     goto fail;
   result = CURLE_OUT_OF_MEMORY;
